@@ -26,6 +26,12 @@
  *
  */
 
+#if !defined(__ASOUNDLIB_H) && !defined(ALSA_LIBRARY_BUILD)
+/* don't use ALSA_LIBRARY_BUILD define in sources outside alsa-lib */
+#warning "use #include <alsa/asoundlib.h>, <alsa/pcm.h> should not be used directly"
+#include <alsa/asoundlib.h>
+#endif
+
 #ifndef __ALSA_PCM_H
 #define __ALSA_PCM_H
 
@@ -33,9 +39,6 @@
 extern "C" {
 #endif
 
-#include <stddef.h>
-#include <stdint.h>
-
 /**
  *  \defgroup PCM PCM Interface
  *  See the \ref pcm page for more details.
